==> zio-aws-chimesdkmessaging_2.13-5.17.126.2-sources.jar: zio/aws/chimesdkmessaging/model/DescribeChannelModeratedByAppInstanceUserResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeChannelModeratedByAppInstanceUserResponse(
    channel: Option[
      zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse = {
    import DescribeChannelModeratedByAppInstanceUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
      .builder()
      .optionallyWith(channel.map(value => value.buildAwsValue()))(_.channel)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
      .wrap(buildAwsValue())
}
object DescribeChannelModeratedByAppInstanceUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse =
      zio.aws.chimesdkmessaging.model
        .DescribeChannelModeratedByAppInstanceUserResponse(
          channel.map(value => value.asEditable)
        )
    def channel: Option[
      zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary.ReadOnly
    ]
    def getChannel: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary.ReadOnly
    ] = AwsError.unwrapOptionField("channel", channel)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
  ) extends zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse.ReadOnly {
    override val channel: Option[
      zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary.ReadOnly
    ] = scala
      .Option(impl.channel())
      .map(value =>
        zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
  ): zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-6.20.42.2-sources.jar: zio/aws/chimesdkmessaging/model/DescribeChannelModeratedByAppInstanceUserResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeChannelModeratedByAppInstanceUserResponse(
    channel: Optional[
      zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse = {
    import DescribeChannelModeratedByAppInstanceUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
      .builder()
      .optionallyWith(channel.map(value => value.buildAwsValue()))(_.channel)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
      .wrap(buildAwsValue())
}
object DescribeChannelModeratedByAppInstanceUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse =
      zio.aws.chimesdkmessaging.model
        .DescribeChannelModeratedByAppInstanceUserResponse(
          channel.map(value => value.asEditable)
        )
    def channel: Optional[
      zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary.ReadOnly
    ]
    def getChannel: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary.ReadOnly
    ] = AwsError.unwrapOptionField("channel", channel)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
  ) extends zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse.ReadOnly {
    override val channel: Optional[
      zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.channel())
      .map(value =>
        zio.aws.chimesdkmessaging.model.ChannelModeratedByAppInstanceUserSummary
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse
  ): zio.aws.chimesdkmessaging.model.DescribeChannelModeratedByAppInstanceUserResponse.ReadOnly =
    new Wrapper(impl)
}
